import React, { useState, useEffect, useMemo, useRef } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import PremButton from '@/components/PremButton';
import useKeepAlive from "@/components/useKeepAlive";
import getcolumns from "./columns";
import { useRequest } from 'ahooks';
import { doFetch } from '@/utils/doFetch';
function Department() {
    let actionRef = useRef();
    const [drawer, setdrawer] = useState({
        open: false,
    });
    const {runAsync } = useRequest(doFetch, {
        manual: true,
        onSuccess: (res, params) => {
            if (res?.code == '0000') {
                actionRef?.current?.reload();
                setdrawer((s) => ({
                    ...s,
                    open: false,
                }));
            }
        },
    });
    const columns = useMemo(() => {
        let defcolumn = getcolumns();
        return defcolumn.concat({
            title: "操作",
            valueType: "option",
            width: 80,
            render: (text, row, _, action) => rightExtra(text, row, _, action),
        });
    }, []);
    const rightExtra = (text, row, _, action) => {
        let ifs = row.children;
        return [
            <PremButton
                key="add"
                btn={{
                    type:"primary",
                    size: "small",
                    onClick: () => {
                        setdrawer(s => {
                            return {
                                ...s,
                                open: true,
                                title: `新增 ${row.title} 下的组织`,
                                val: 'add',
                                item:{
                                    key:row.key
                                }
                            }
                        })
                    },
                }}
            >
                新增下级
            </PremButton>,
            <PremButton
                key="edit"
                btn={{
                    type: 'primary',
                    size: "small",
                    onClick: () => {
                        setdrawer(s => {
                            return {
                                ...s,
                                open: true,
                                title: `修改${row.title}`,
                                val: 'edit',
                                item: {
                                    ...row,
                                    departmentName:row.title
                                }
                            }
                        })
                    },
                }}
            >
                修改
            </PremButton>,
            !ifs && <PremButton
                key='delete'
                pop={{
                    title: "是否删除该组织?",
                    okText: "确认",
                    cancelText: "取消",
                    onConfirm: async () => {
                        await runAsync({
                            url: "/ta_wms_auth/sysDepartment/deleteById",
                            params: { id: row.key },
                        });
                    },
                }}
                btn={{
                    size: "small",
                    danger: true
                }}
            >
                删除
            </PremButton>
        ];
    };
    return <div>
        <AutoTable
            pagetitle='组织管理'
            columns={columns}
            path='/ta_wms_auth/sysDepartment/query/tree'
            actionRef={actionRef}
            rowKey='key'
            pageextra='add'
            addconfig={{
                // access: 'sysDepartment_save',
                name: '新增',
                btn: {
                    type: 'primary',
                    onClick: () => {
                        setdrawer((s) => ({
                            ...s,
                            open: true,
                            title: '新增',
                            val: 'add',
                            item: {
                                key:'0'
                            }
                        }));
                    },
                },
            }}
            pagination={false}
        />
        <DrawerPro
            {...drawer}
            fields={columns}
            defaultFormValue={drawer?.item}
            placement="right"
            onClose={() => {
                setdrawer((s) => ({
                    ...s,
                    open: false,
                }));
            }}
            onFinish={async (vals) => {
                let newfields = JSON.parse(JSON.stringify(vals));
                let difrid = drawer.val == "edit" ? { id: drawer.item.key } : { parentId: drawer.item.key };
                await runAsync({
                    url: "/ta_wms_auth/sysDepartment/save",
                    params: { ...newfields, ...difrid },
                });
            }}
            width='40%'
        />
    </div>;
}

export default useKeepAlive(Department);